==> all_in_one_basic-0.1.3.tar.gz: lib/all_in_one_basic.dart <==
import 'dart:async';

import 'package:flutter/services.dart';

class AllInOneBasic {
  static const MethodChannel _channel = MethodChannel('all_in_one_basic');

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  static Future<void> share(String message) async {
    await _channel.invokeMethod('share', {'message':message});
  }
  
  static Future<void> showToast(String message, String duration) async {
    await _channel.invokeMethod('showToast', {'message':message, 'duration':duration});
  }

  static Future<bool> internet() async {
    final bool getInternet =  await _channel.invokeMethod('internet');
    return getInternet;
  }

  static Future<String> internetType() async {
    final String getInternetType = await _channel.invokeMethod('internetStream');
    return getInternetType;
  }

  static Future<String> randomNumbers(int min, int max) async {
    final String getRandomNumbers =  await _channel.invokeMethod('randomNumbers', {'min':min, 'max':max});
    return getRandomNumbers;
  }

  static Future<String> randomAlphaNumeric(int digits) async {
    final String getRandomAlphaNumeric =  await _channel.invokeMethod('randomAlphaNumeric', {'digits':digits});
    return getRandomAlphaNumeric;
  }

  static setSharedPreferencesString(String key, String value) async {
    await _channel.invokeMethod('setSharedPreferencesString', {'key':key, 'value':value});
  }

  static setSharedPreferencesInteger(String key, String value) async {
    await _channel.invokeMethod('setSharedPreferencesString', {'key':key, 'value':value});
  }

  static setSharedPreferencesBoolean(String key, String value) async {
    await _channel.invokeMethod('setSharedPreferencesString', {'key':key, 'value':value});
  }

  static Future<String> getSharedPreferencesString(String key) async {
    return await _channel.invokeMethod('getSharedPreferencesString', {'key':key});
  }

  static Future<String> getSharedPreferencesInteger(String key) async {
    return await _channel.invokeMethod('getSharedPreferencesInteger', {'key':key});
  }

  static Future<String> getSharedPreferencesBoolean(String key) async {
    return await _channel.invokeMethod('getSharedPreferencesBoolean', {'key':key});
  }
}

==> all_in_one_basic-0.1.4.tar.gz: lib/all_in_one_basic.dart <==
import 'dart:async';

import 'package:flutter/services.dart';

class AllInOneBasic {
  static const MethodChannel _channel = MethodChannel('all_in_one_basic');

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  static Future<void> share(String message) async {
    await _channel.invokeMethod('share', {'message':message});
  }
  
  static Future<void> showToast(String message, String duration) async {
    await _channel.invokeMethod('showToast', {'message':message, 'duration':duration});
  }

  static Future<bool> internet() async {
    final bool getInternet =  await _channel.invokeMethod('internet');
    return getInternet;
  }

  static Future<String> internetType() async {
    final String getInternetType = await _channel.invokeMethod('internetStream');
    return getInternetType;
  }

  static Future<String> randomNumbers(int min, int max) async {
    final String getRandomNumbers =  await _channel.invokeMethod('randomNumbers', {'min':min, 'max':max});
    return getRandomNumbers;
  }

  static Future<String> randomAlphaNumeric(int digits) async {
    final String getRandomAlphaNumeric =  await _channel.invokeMethod('randomAlphaNumeric', {'digits':digits});
    return getRandomAlphaNumeric;
  }

  static setSharedPreferencesString(String key, String value) async {
    await _channel.invokeMethod('setSharedPreferencesString', {'key':key, 'value':value});
  }

  static setSharedPreferencesInteger(String key, int value) async {
    await _channel.invokeMethod('setSharedPreferencesString', {'key':key, 'value':value});
  }

  static setSharedPreferencesBoolean(String key, bool value) async {
    await _channel.invokeMethod('setSharedPreferencesString', {'key':key, 'value':value});
  }

  static Future<String> getSharedPreferencesString(String key) async {
    return await _channel.invokeMethod('getSharedPreferencesString', {'key':key});
  }

  static Future<int> getSharedPreferencesInteger(String key) async {
    return await _channel.invokeMethod('getSharedPreferencesInteger', {'key':key});
  }

  static Future<bool> getSharedPreferencesBoolean(String key) async {
    return await _channel.invokeMethod('getSharedPreferencesBoolean', {'key':key});
  }
}
